pub enum LoadError {
UnsupportedFormat,
UnsupportedFeature,
Parse,
Decode,
Io,
NotFound,
}Expand description
Asset loading errors.
Variants
UnsupportedFormat
The input format is unsupported.
UnsupportedFeature
The source uses a known format feature that scenix does not support yet.
Parse
The input bytes or text could not be parsed.
Decode
The input could not be decoded.
Io
An IO or network request failed.
NotFound
The requested asset was not found.